;///////////////////////////////////////////////////////////////////////////////////
; Example code to use the TAV20 library
;///////////////////////////////////////////////////////////////////////////////////
; Last modified: 26-Dic-2020
;
; 26-12-2020	First version.
;========================================================================================

; Variables

; Constants

	CHROUT = $FFD2		; Kernal's CHROUT routine
	Speak  = $176C		; Entry point to the speech synth

	!to "tav20usr.prg", cbm

	*= $1001

;///////////////////////////////////////////////////////////////////////////////////
; BASIC program
;///////////////////////////////////////////////////////////////////////////////////

	!byte $0C, $10, $E4, $07, $9E, $20, $34, $31, $31, $30, $00	; 2020 SYS 4110
	!byte $00, $00

;///////////////////////////////////////////////////////////////////////////////////
; Speech synth binary ($100E)
;///////////////////////////////////////////////////////////////////////////////////

;	*= $100E

	!binary "tav20lib.bin"

;///////////////////////////////////////////////////////////////////////////////////
; Start of user code
;///////////////////////////////////////////////////////////////////////////////////

Start				; TAV20lib jumps here after initialization
	JMP	MainPrg

;///////////////////////////////////////////////////////////////////////////////////
; SUBROUTINES
;///////////////////////////////////////////////////////////////////////////////////

;///////////////////////////////////////////////////////////////////////////////////
; STROUT routine. Parameters: Y = high byte of address, A = low byte of address
; Address must point to a null-terminated string to print.

STROUT
	STA	SOLoop+1	; Puts the address Y:A replacing $FFFF
	STY	SOLoop+2	; (self-modifying code)
	LDX	#0		; X = 0
SOLoop
	LDA	$FFFF, X	; Reads a char
	BEQ	SOEnd		; If zero jumps to SOEnd
	JSR	CHROUT		; prints the character
	INX			; X++
	JMP	SOLoop
SOEnd
	RTS			; Returns

;///////////////////////////////////////////////////////////////////////////////////
; Main program
;///////////////////////////////////////////////////////////////////////////////////

MainPrg

; Pixel's volume boost code	http://sleepingelephant.com/ipw-web/bulletin/bb/viewtopic.php?f=2&t=9912

	LDA	#$7E		; Stop channels.
	STA	$900A
	STA	$900B
	STA	$900C
	STA	$900D

	; Let channels rest until LSFRs are empty.
	; Some extra explaining why that takes so long
	; would be nice.

	LDY	#0
-	DEY
	BNE	-

	; Start alto channel at highest frequency of
	; ~8659Hz, which is 128 CPU cycles.
	LDA	#$FE
	STA	$900B

	; Waste 56 cycles.
	; 2+10*5+4
	LDY	#11		; 2
-	DEY			; 2
	BNE	-		; 3

	; Waste missing 2 cycles.
	NOP			; 2

	; Start soprano channel at same frequency as alto.
	; Takes 6 cycles. Then it's exactly half a wave
	; (64 cycles) apart from the alto.
	; Complain to my weed dealer if I'm wrong.                                                                                                                
	LDA	#$FD		; 2
	STA	$900C		; 4

; End of pixel's code

	LDA	#8		; Volume 8
	STA	$900E

	LDA	#<Msg01		; Prints Msg01
	LDY	#>Msg01
	JSR	STROUT

	LDA	#<Speech01	; Process Speech01
	LDY	#>Speech01
	JSR	Speak

	LDA	#<Msg02		; Prints Msg02
	LDY	#>Msg02
	JSR	STROUT

	LDA	#<Speech02	; Process Speech02
	LDY	#>Speech02
	JSR	Speak

	LDA	#<Msg03		; Prints Msg03
	LDY	#>Msg03
	JSR	STROUT

	LDA	#<Speech03	; Process Speech03
	LDY	#>Speech03
	JSR	Speak
ExitPrg
	RTS			; Returns to BASIC

;///////////////////////////////////////////////////////////////////////////////////
; Messages
;///////////////////////////////////////////////////////////////////////////////////

Msg01
;	       1234567890123456789012
	!byte 142, 144, 147, 28	; Upper case, black ink, clear screen, red ink
	!text "TAV20 V1.0 (2020)[PCM]"
	!fill 22, 163
	!byte 0
Msg02
	!byte 156		; magenta
	!text "SINTETIZADOR LISTO."
	!byte 13, 13
	!byte 144, 0		; black
Msg03
	!text "<A-A-AAA+A+>A-A-AAA+A+"
	!byte 13, 0

Speech01
	!text "TE+KSTO ABO+S,BE+INTE."
	!byte 0
Speech02
	!text "<SINTETISADO+R LI+STO->."
	!byte 0
Speech03
	!text "<A-A-AAA+A+>A-A-AAA+A+,"
	!byte 0
